@@ -146,7 +146,10 @@ def kde(ctx, arg1, **kwargs):
         clk.echo_args(arg1, **kwargs)
     else:
         try:
-            aS = np.loadtxt(arg1)[:,kwargs['idx']]
+            aS = np.loadtxt(arg1)
+            if len(aS.shape) < 2:
+                aS = aS.reshape(-1, 1)
+            aS = aS[:, kwargs['idx']]
             ssize = hs.kde_cont(aS, kwargs['resample'], kwargs['sigma'])
             if kwargs['scale'] is not None:
                 scale = kwargs['scale']/len(aS)
