@@ -47,7 +47,8 @@ def corr_header(lin=True, spearman=False, pearson=False, pvals=True, rbc=False,
 
 
 def rel_error(x, y):
-    return np.where(np.abs(y) > 0, 1 - x/y, np.where(np.abs(x) > 0, 1, 0))
+    with np.errstate(divide='ignore', invalid='ignore'):
+        return np.where(np.abs(y) > 0, 1 - x/y, np.where(np.abs(x) > 0, 1, 0))
 
 def corr_calc(x, y, lin=True, spearman=False, pearson=False, pvals=True,
               rbc=False, rmse=False, rrmse=False, mae=False, rmae=False,
@@ -72,14 +73,14 @@ def corr_calc(x, y, lin=True, spearman=False, pearson=False, pvals=True,
     if not pvals:
         out = out[0::2]
     if rmse:
-        err = (np.sum(y-x)**2/len(x))**.5
+        err = (np.sum((y-x)**2)/len(x))**.5
         out += [err]
     if mae:
         err = np.sum(np.abs(y-x))/len(x)
         out += [err]
     if rrmse:
         rerr = rel_error(x, y)
-        err = (np.sum(rerr)**2/len(x))**.5
+        err = (np.sum(rerr**2)/len(x))**.5
         out += [err]
     if rmae:
         rerr = rel_error(x, y)
@@ -218,19 +219,22 @@ def kernel(d, w=None, mi=None, mx=None, n=1000, t=1e-4, bws=.5):
         d = d[w >= t]
         w = w[w >= t]
         neff = np.sum(w)**2 / np.sum(w**2)
-    k = stats.gaussian_kde(d, weights=w, bw_method=neff**(-1./(1+4))*bws)
-    if mi is None:
-        mi = np.min(d)
-    if mx is None:
-        mx = np.max(d)
-    inc = (mx - mi)/(n+1)
-    vstats = {}
-    vstats['min'] = mi
-    vstats['max'] = mx
-    vstats['median'] = weighted_median(d, w, t)
-    vstats['mean'] = np.average(d, weights=w)
-    vstats['coords'] = np.arange(mi, mx+inc/2, inc)
-    vstats['vals'] = k(vstats['coords'])
+    try:
+        k = stats.gaussian_kde(d, weights=w, bw_method=neff**(-1./(1+4))*bws)
+    except np.linalg.LinAlgError:
+        vstats = {'min': 0, 'max': 0, 'median': 0, 'mean': 0,
+                  'coords': [0], 'vals': [0]}
+    else:
+        if mi is None:
+            mi = np.min(d)
+        if mx is None:
+            mx = np.max(d)
+        inc = (mx - mi)/(n+1)
+        vstats = {'min': mi, 'max': mx, 'median': weighted_median(d, w, t),
+                  'mean': np.average(d, weights=w),
+                  'coords': np.arange(mi, mx + inc/2, inc)
+                  }
+        vstats['vals'] = k(vstats['coords'])
     return vstats
 
 
